# Crowdstrike MISP Importer Tool

## Legal notice

By accessing or using this script, sample code, application programming interface, tools, and/or associated
documentation (if any) (collectively, “Tools”), You (i) represent and warrant that You are entering into this Agreement
on behalf of a company, organization or another legal entity (“Entity”) that is currently a customer or partner of
CrowdStrike, Inc.(“CrowdStrike”), and (ii) have the authority to bind such Entity and such Entity agrees to be bound by
this Agreement. CrowdStrike grants Entity a non-exclusive, non-transferable, non-sublicensable, royalty free and limited
license to access and use the Tools solely for Entity’s internal business purposes and in accordance with its
obligations under any agreement(s) it may have with CrowdStrike. Entity acknowledges and agrees that CrowdStrike and its
licensors retain all right, title and interest in and to the Tools, and all intellectual property rights embodied
therein, and that Entity has no right, title or interest therein except for the express licenses granted hereunder and
that Entity will treat such Tools as CrowdStrike’s confidential information.

THE TOOLS ARE PROVIDED “AS-IS” WITHOUT WARRANTY OF ANY KIND, WHETHER EXPRESS, IMPLIED OR STATUTORY OR OTHERWISE.
CROWDSTRIKE SPECIFICALLY DISCLAIMS ALL SUPPORT OBLIGATIONS AND ALL WARRANTIES, INCLUDING WITHOUT LIMITATION, ALL IMPLIED
WARRANTIES OF MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT. IN NO EVENT SHALL
CROWDSTRIKE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
THE USE OF THE TOOLS, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

© Copyright CrowdStrike 2019-20



## Description

Crowdstrike MISP Importer Tool is a tool used to import data from the Crowdstrike Intel API in your MISP instance. It pulls reports, indicators and actors from Intel API and pushes them into MISP via MISP API. It creates a new event for every report, indicator and actor document imported and adds them some attributes or object for some of their components. In the case of an indicator, after it is created as an event, it is also added as an attribute on every one of its related reports (if they are imported).



## Configuration

### Configure your MISP instance.

- Add the needed tags (unique tags set for indicators, actors and reports and additional tags selected) in the settings.py file. Make sure the UNIQUE tags are UNIQUE. If not, the features of the tool that delete/cleanup MISP events will delete all your events with that tag. Make sure you set an unique tag for each category. You can do this from the main page ```Event Actions -> Add Tag```.
   
- If you don't have it, create an organisation for Crowdstrike.
You can do this from the main page, ```Administration -> Add Organisations```.
    
### Configure the tool (settings.py file).

- Set your client ID and client secret.

- Set the URL for the Crowdstrike API. This is set by default to ```https://api.crowdstrike.com```.

- Configure the tool settings. These settings include the names of the files in which to save the last confirmed
reports, indicators and actors and the maximum age (in days) of the objects pulled.

- Configure the settings referring to your MISP instance. These include de URL for your MISP instance, the
authentification key for the user inserting the events in MISP and the UUID of the Crowdstrike organisation in your
MISP instance.



## Usage

### Optional clean.

Run a cleaning run of the script. This will remove all the Crowdstrike events in your MISP instance. You can skip this 
if you don't have events tagged with the tags that this script uses or if you don't want to delete the events.

```bash
python3 /path/to/cs-misp-importer/cs-misp-importer/cs-misp-importer.py --clean_reports --clean_indicators --clean_actors
```

### Periodic update.

Set up a cron job that will periodically run and pull the latest obejcts from the Crowdstrike API
and push them as events in your MISP instance. To do this run the following commands.

```bash
crontab -e
```

This will let you edit your crontab file. Add the following line at the end of the file.

```bash
0 0 * * * python3 /path/to/cs-misp-importer/cs-misp-importer/cs-misp-importer.py --reports --related_indicators --actors --max_age 14 2>&1 | /usr/bin/logger -t CS-MISP-IMPORTER
```

This will configure a cron job to run this script daily. If you want to have another configuration (hourly, every
25 minutes, etc) you can find information online about configuring a cron job. You can find the logs of the each run
in the ```/var/log/syslog``` file. You can also redirect the output of that command in another file but you will have 
to manage log rotation.

Moreover, this configures the tool to import reports, actors and only the indicators that are related to a report that 
is already in your MISP instance. Run the following command for more options:
   
```bash
python3 /path/to/cs-misp-importer/cs-misp-importer/cs-misp-importer.py --help
```

### Options explained

#### Cleanup related options
- --clean_report → deletes all events with the unique report tag and the file containing the timestamp of the last Crowdstrike report imported
- --clean_indicators → deletes all events with the unique indicator tag and the file containing the timestamp of the last Crowdstrike indicator imported
- --clean_actors → deletes all events with the unique actor tag and the file containing the timestamp of the last Crowdstrike actor imported

#### Import related options
- --reports → import report documents
- --all_indicators → import ALL indicators (this might incapacitate MISP due to the very high number of events and documents, use at own risk)
- --related_indicators → import only indicators that are related to a report that was already imported (recommended option for indicators)
- --max_age → after an import run, delete events with timestamp older than max_age
- --delete_outdated_indicators → automatically delete indicators Crowdstrike considers obsolete, not taking into account their age

#### General options
- --debug → add more debug logs
- --help → show help



## Dependencies

To run this script, you need Python3 and the Python packages in the requirements.txt file (make sure PyMISP is at version 2.4.117.2)



## Data Mapping

#### Reports → MISP Events (Info = Report name, Threat Level = Undefined, Analysis = Completed)
- url → attribute with category "External analysis" and type "link" on the event
- short_description → attribute with category "Other" and type "comment" on the event
- actors → each actor maps to an attribute with category "Attribution" and type "threat-actor" on the event
- target_countries → each country maps to an object of type "victim" with and attribute with category "Targeting data" 
and type "regions" on the event
- target_industries → each industry maps to an object of type "victim" with and attribute with category "Other" and 
type "sectors" on the event
- tagged as "CrowdstrikeReport"

#### Indicators → MISP Events (Info = Indicator, Threat Level = Indicator Malicious Confidence, Analysis
- indicator and type → this pair is mapped to attributes/objects on the event.
    - types not mapped : binary_string, event_name, persona_name, file_author, ip_address_block
    - the same attribute/object is added on all the events corresponding to the events in the "reports" list of the 
    indicator
- actors → each actor maps to an attribute with category "Attribution" and type "threat-actor" on the event
- targets → each target maps to an object of type "victim" with and attribute with category "Other" and type "sectors" 
on the event
- malware_families → each malware_family is mapped to a MISP galaxy/cluster (ex. "Tinba" is mapped as 
'misp-galaxy:banker="Tinba"'). Only some malware families are mapped to galaxies.
- tagged as "CrowdstrikeIndicator"

#### Actors → MISP Events (Info = Actor name, Threat Level = Undefined, Analysis = Completed)
- url → attribute with category "External analysis" and type "link" on the event
- short_description → attribute with category "Other" and type "comment" on the event
- known_as → object of type "organisation" with attribute with category "Other and type "comment" on the event
- first_activity_date → object of type "timestamp" with attribute with category "Other" and type "timestamp" on the event
- last_activity_date → object of type "timestamp" with attribute with category "Other" and type "timestamp" on the event
- target_countries → each country maps to an object of type "victim" with and attribute with category "Targeting data" 
and type "regions" on the event
- target_industries → each industry maps to an object of type "victim" with and attribute with category "Other" and 
type "sectors" on the event
- tagged as "CrowdstrikeActor"



## Security concerns
- Exposes API
- Exposes format of JSON requests and responses



## Distribution to clients (not decided yet)
Either open source or sent as an archive.



## Improvements needed

- [ ] Better mapping of fields from the Crowdstrike data model to the MISP model. Currently, some of them are left out.
- [x] Remove indicators that aged out or we want removed (feature from Intel API).
- [x] Let the customer set a maximum age of the Crowdstrike events in their instance and delete the older ones (ex. I want events not older than 2 months).
- [x] Let the customer chose which type of data (reports/indicators/actors) they want to add or remove (ex. add only the reports and indicators, clean the actors).
- [x] Add only indicators that are related to reports.
