"""
By accessing or using this script, sample code, application programming interface, tools, and/or associated
documentation (if any) (collectively, “Tools”), You (i) represent and warrant that You are entering into this Agreement
on behalf of a company, organization or another legal entity (“Entity”) that is currently a customer or partner of
CrowdStrike, Inc.(“CrowdStrike”), and (ii) have the authority to bind such Entity and such Entity agrees to be bound by
this Agreement. CrowdStrike grants Entity a non-exclusive, non-transferable, non-sublicensable, royalty free and limited
license to access and use the Tools solely for Entity’s internal business purposes and in accordance with its
obligations under any agreement(s) it may have with CrowdStrike. Entity acknowledges and agrees that CrowdStrike and its
licensors retain all right, title and interest in and to the Tools, and all intellectual property rights embodied
therein, and that Entity has no right, title or interest therein except for the express licenses granted hereunder and
that Entity will treat such Tools as CrowdStrike’s confidential information.

THE TOOLS ARE PROVIDED “AS-IS” WITHOUT WARRANTY OF ANY KIND, WHETHER EXPRESS, IMPLIED OR STATUTORY OR OTHERWISE.
CROWDSTRIKE SPECIFICALLY DISCLAIMS ALL SUPPORT OBLIGATIONS AND ALL WARRANTIES, INCLUDING WITHOUT LIMITATION, ALL IMPLIED
WARRANTIES OF MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT. IN NO EVENT SHALL
CROWDSTRIKE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
THE USE OF THE TOOLS, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

© Copyright CrowdStrike 2019-20
"""

"""
        Crowdstrike API configurations. Client ID, client secret and the Intel API URL.
"""
client_id = ""
client_secret = ""
crowdstrike_url = "https://api.crowdstrike.com"


"""
        Tool configurations. The files in which to store the last updated timestamp and the max age of the
    reports/indicators/actors pulled in an initial run.
"""
reports_timestamp_filename = "lastReportsUpdate.dat"
indicators_timestamp_filename = "lastIndicatorsUpdate.dat"
actors_timestamp_filename = "lastActorsUpdate.dat"

init_reports_days_before = 7
init_indicators_days_before = 7
init_actors_days_before = 7

reports_unique_tag = "CRWD_REP"
indicators_unique_tag = "CRWD_IND"
actors_unique_tag = "CRWD_ACT"

reports_tags = [reports_unique_tag, "REPORT", "CROWDSTRIKE", "NEWS"]
indicators_tags = [indicators_unique_tag, "INDICATOR", "CROWDSTRIKE"]
actors_tags = [actors_unique_tag, "ACTOR", "CROWDSTRIKE"]


"""
        MISP configurations. The URL of your MISP instance, the authentification key of the user adding the events and 
    the UUID of the Crowdstrike organisation in your MISP instance.
"""
misp_url = ""
misp_auth_key = ""
crowdstrike_org_uuid = ""

"""
        Mapping used to map the malware families in Crowdstrike Intel API to MISP galaxies.
        https://www.misp-project.org/galaxy.html
"""
malware_family_to_galaxy_mapping = {
    "njRAT": 'misp-galaxy:malpedia="NjRAT"',
    "Qakbot": 'misp-galaxy:banker="Qakbot"',
    "Tinba": 'misp-galaxy:banker="Tinba"',
    "Nymaim": 'misp-galaxy:malpedia="Nymaim"',
    "Pony": 'misp-galaxy:malpedia="Pony"',
    "Sakula": 'misp-galaxy:rat="Sakula"',
    "LokiBot": 'misp-galaxy:android="LokiBot"',
    "DarkComet": 'misp-galaxy:malpedia="DarkComet"',
    "GandCrab": 'misp-galaxy:malpedia="Gandcrab"',
    "Geodo": 'misp-galaxy:banker="Geodo"',
    "PoisonIvy": 'misp-galaxy:malpedia="Poison Ivy"',
    "Kovter": 'misp-galaxy:malpedia="Kovter"',
    "CoreBot": 'misp-galaxy:banker="Corebot"',
    "Emotet": 'misp-galaxy:malpedia="Emotet"',
    "X-Agent": 'misp-galaxy:tool="X-Agent"',
    "Gozi": 'misp-galaxy:banker="Gozi"',
    "ISFB": 'misp-galaxy:malpedia="ISFB"',
    "Andromeda": 'misp-galaxy:malpedia="Andromeda"',
    "Kronos": 'misp-galaxy:malpedia="Kronos"',
    "AgentTesla": 'misp-galaxy:tool="Agent Tesla"',
    "Azorult": 'misp-galaxy:malpedia="Azorult"',
    "Rifdoor": 'misp-galaxy:malpedia="Rifdoor"',
    "Ursnif": 'misp-galaxy:mitre-malware="Ursnif - S0386"',
    "FormBook": 'misp-galaxy:malpedia="Formbook"',
    "XtremeRAT": 'misp-galaxy:rat="XtremeRAT"',
    "Excalibur": 'misp-galaxy:malpedia="Excalibur"',
    "Sekur": 'misp-galaxy:tool="Sekur"',
    "Netwire": 'misp-galaxy:rat="Netwire"',
    "Dridex": 'misp-galaxy:tool="Dridex"',
    "URLZone": 'misp-galaxy:malpedia="UrlZone"',
    "SolarBot": 'misp-galaxy:malpedia="Solarbot"',
    "Gh0stRAT": 'misp-galaxy:tool="Gh0st Rat"',
    "Taleret": 'misp-galaxy:malpedia="Taleret"'
}
